printer_tsc

A new Flutter plugin project.

flutter create --org cn.com.bx --template=plugin --platforms=android,windows -a java printer_tsc

Getting Started

This project is a starting point for a Flutter plug-in package, a specialized package that includes platform-specific implementation code for Android and/or iOS.

For help getting started with Flutter development, view the online documentation, which offers tutorials, samples, guidance on mobile development, and a full API reference.