PrinterStatus enum

Inheritance
Available extensions

Values

idle → const PrinterStatus
headOpened → const PrinterStatus
paperJam → const PrinterStatus
paperJamAndHeadOpened → const PrinterStatus
paperEmpty → const PrinterStatus
paperEmptyAndHeadOpened → const PrinterStatus
ribbonEmpty → const PrinterStatus
ribbonEmptyAndHeadOpened → const PrinterStatus
ribbonEmptyAndPaperJam → const PrinterStatus
ribbonEmptyAndPaperJamAndHeadOpened → const PrinterStatus
ribbonEmptyAndPaperEmpty → const PrinterStatus
ribbonEmptyAndPaperEmptyAndHeadOpened → const PrinterStatus
paused → const PrinterStatus
printing → const PrinterStatus
otherError → const PrinterStatus
unknown → const PrinterStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PrinterStatus>
A constant List of the values in this enum, in order of their declaration.