MethodChannelPrinterTsc class
An implementation of PrinterTscPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- PrinterTscPlatform
- MethodChannelPrinterTsc
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
barcode(
int x, int y, BarcodeType barcodeType, int height, HumanReadable readable, Rotation rotation, int narrow, int wide, String content) → Future< bool> -
override
-
clearBuffer(
) → Future< bool> -
override
-
close(
) → Future< bool> -
override
-
downloadbmp(
String fileName) → Future< bool> -
override
-
downloadpcx(
String fileName) → Future< bool> -
override
-
downloadttf(
String fileName) → Future< bool> -
override
-
formfeed(
) → Future< bool> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
nobackfeed(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openBluetoothPort(
String macAddress) → Future< bool> -
override
-
openEthernetPort(
String ipAddress, String port) → Future< bool> -
override
-
openPortForWindows(
String portName) → Future< bool> -
override
-
openUsbPort(
{int? timeoutMs}) → Future< bool> -
override
-
printerfont(
int x, int y, String size, Rotation rotation, int xMultiplication, int yMultiplication, String content) → Future< bool> -
override
-
printerstatus(
int timeoutMs) → Future< PrinterStatus?> -
override
-
printlabel(
int labelSetCount, int copyCount) → Future< bool> -
override
-
sendcommand(
String command) → Future< bool> -
override
-
sendfile(
String fileName) → Future< bool> -
override
-
setup(
int labelWidthMm, int labelHeightMm, int printSpeed, int density, LabelSensorType sensorType, int sensorDistanceMm, int sensorOffsetMm) → Future< bool> -
override
-
smartbatteryStatus(
SmartBatteryStatusType statusType) → Future< String?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
windowsfont(
int x, int y, int fontheight, int rotation, int fontstyle, int fontunderline, String szFaceName, String content) → Future< bool> -
Prints text using a Windows TrueType font (Windows-only).
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited