- Inheritance
-
- Object
- PlatformInterface
- PrinterTscPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
barcode(int x, int y, BarcodeType barcodeType, int height, HumanReadable readable, Rotation rotation, int narrow, int wide, String content)
→ Future<bool>
-
-
clearBuffer()
→ Future<bool>
-
-
close()
→ Future<bool>
-
-
downloadbmp(String fileName)
→ Future<bool>
-
-
downloadpcx(String fileName)
→ Future<bool>
-
-
downloadttf(String fileName)
→ Future<bool>
-
-
formfeed()
→ Future<bool>
-
-
getPlatformVersion()
→ Future<String?>
-
-
nobackfeed()
→ Future<bool>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
openBluetoothPort(String macAddress)
→ Future<bool>
-
-
openEthernetPort(String ipAddress, String port)
→ Future<bool>
-
-
openPortForWindows(String portName)
→ Future<bool>
-
-
openUsbPort({int? timeoutMs})
→ Future<bool>
-
-
printerfont(int x, int y, String size, Rotation rotation, int xMultiplication, int yMultiplication, String content)
→ Future<bool>
-
-
printerstatus(int timeoutMs)
→ Future<PrinterStatus?>
-
-
printlabel(int labelSetCount, int copyCount)
→ Future<bool>
-
-
sendcommand(String command)
→ Future<bool>
-
-
sendfile(String fileName)
→ Future<bool>
-
-
setup(int labelWidthMm, int labelHeightMm, int printSpeed, int density, LabelSensorType sensorType, int sensorDistanceMm, int sensorOffsetMm)
→ Future<bool>
-
-
smartbatteryStatus(SmartBatteryStatusType statusType)
→ Future<String?>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
windowsfont(int x, int y, int fontheight, int rotation, int fontstyle, int fontunderline, String szFaceName, String content)
→ Future<bool>
-
Prints text using a Windows TrueType font (Windows-only).